"use strict";
Object.defineProperty(exports, "__esModule", { value: true });
const typescript_1 = require("../../../typescript");
/** @internal */
var ExtendedCommentKind;
(function (ExtendedCommentKind) {
    ExtendedCommentKind[ExtendedCommentKind["Statement"] = 0] = "Statement";
    ExtendedCommentKind[ExtendedCommentKind["ClassElement"] = 1] = "ClassElement";
    ExtendedCommentKind[ExtendedCommentKind["TypeElement"] = 2] = "TypeElement";
    ExtendedCommentKind[ExtendedCommentKind["ObjectLiteralElement"] = 3] = "ObjectLiteralElement";
    ExtendedCommentKind[ExtendedCommentKind["EnumMember"] = 4] = "EnumMember";
})(ExtendedCommentKind = exports.ExtendedCommentKind || (exports.ExtendedCommentKind = {}));
class CompilerExtendedComment {
    /** @private */
    constructor(fullStart, pos, end, kind, sourceFile, parent) {
        this._fullStart = fullStart;
        this._start = pos; // pos and start are the same for comments
        this._sourceFile = sourceFile;
        this.pos = pos;
        this.end = end;
        this.kind = kind;
        this.flags = typescript_1.ts.NodeFlags.None;
        this.parent = parent;
    }
    getSourceFile() {
        return this._sourceFile;
    }
    getChildCount(sourceFile) {
        return 0;
    }
    getChildAt(index, sourceFile) {
        return undefined; // the compiler definition is wrong
    }
    getChildren(sourceFile) {
        return [];
    }
    getStart(sourceFile, includeJsDocComment) {
        return this._start;
    }
    getFullStart() {
        return this._fullStart;
    }
    getEnd() {
        return this.end;
    }
    getWidth(sourceFile) {
        return this.end - this._start;
    }
    getFullWidth() {
        return this.end - this._fullStart;
    }
    getLeadingTriviaWidth(sourceFile) {
        return this._start - this._fullStart;
    }
    getFullText(sourceFile) {
        return this._sourceFile.text.substring(this._fullStart, this.end);
    }
    getText(sourceFile) {
        return this._sourceFile.text.substring(this._start, this.end);
    }
    getFirstToken(sourceFile) {
        return undefined;
    }
    getLastToken(sourceFile) {
        return undefined;
    }
    forEachChild(cbNode, cbNodeArray) {
        return undefined;
    }
}
exports.CompilerExtendedComment = CompilerExtendedComment;
class CompilerCommentStatement extends CompilerExtendedComment {
    constructor() {
        super(...arguments);
        /** @internal */
        this._commentKind = ExtendedCommentKind.Statement;
    }
}
exports.CompilerCommentStatement = CompilerCommentStatement;
class CompilerCommentClassElement extends CompilerExtendedComment {
    constructor() {
        super(...arguments);
        /** @internal */
        this._commentKind = ExtendedCommentKind.ClassElement;
    }
}
exports.CompilerCommentClassElement = CompilerCommentClassElement;
class CompilerCommentTypeElement extends CompilerExtendedComment {
    constructor() {
        super(...arguments);
        /** @internal */
        this._commentKind = ExtendedCommentKind.TypeElement;
    }
}
exports.CompilerCommentTypeElement = CompilerCommentTypeElement;
class CompilerCommentObjectLiteralElement extends CompilerExtendedComment {
    constructor() {
        super(...arguments);
        /** @internal */
        this._commentKind = ExtendedCommentKind.ObjectLiteralElement;
    }
}
exports.CompilerCommentObjectLiteralElement = CompilerCommentObjectLiteralElement;
class CompilerCommentEnumMember extends CompilerExtendedComment {
    constructor() {
        super(...arguments);
        /** @internal */
        this._commentKind = ExtendedCommentKind.EnumMember;
    }
}
exports.CompilerCommentEnumMember = CompilerCommentEnumMember;
